//
//  YHServiceCenterSecondViewController.swift
//  galaxy
//
//  Created by davidhuangA on 2024/1/24.
//  Copyright © 2024 https://www.galaxy-immi.com. All rights reserved.
//

import UIKit

//服务中心
class YHServiceCenterSecondViewController: YHBaseViewController {
    
    private let serviceCenterMainReqVM : YHServiceCenterMainViewModel = YHServiceCenterMainViewModel()
    private var unfoldFlag : Bool = true //是否展开
    private lazy var downArrowImagev : UIImageView =  {
        
        let imagV = UIImageView(frame: CGRect(x: KScreenWidth - 16 - 32, y: 16, width: 28, height: 28))
        imagV.image = UIImage(named: "service_center_down_arrow")
        imagV.contentMode = .scaleAspectFill
//        view.addSubview(imagV)
        return imagV
    }()
    
    private lazy var topBkg : UIView = {
        let imagV = UIImageView()
        imagV.image = UIImage(named: "service_center_head_bkg")
        imagV.contentMode = .scaleAspectFill
        return imagV
        
    }()
    
    private let loginTipsView : YHLoginTipsView = {
        let view = YHLoginTipsView()
        view.viewType = 0
        view.isHidden = true
        return view
    }()
    
    private let noDataView : YHLoginTipsView = {
        let view = YHLoginTipsView()
        view.viewType = 1
        view.isHidden = true
        return view
    }()
    
    
    var homeTableView: UITableView = {
        let tableView = UITableView(frame: .zero, style: .grouped)
        tableView.backgroundColor = .clear
        tableView.separatorStyle = .none
        tableView.showsHorizontalScrollIndicator = false
        tableView.showsVerticalScrollIndicator = false
        tableView.rowHeight = UITableView.automaticDimension
        tableView.estimatedRowHeight = 81.0
        tableView.register(YHContractCell.self,forCellReuseIdentifier: YHContractCell.cellReuseIdentifier)
        tableView.register(UITableViewCell.self,forCellReuseIdentifier: "cell")
        return tableView
    }()
    
    override func viewDidLoad() {
        super.viewDidLoad()
        setupUI()
        loadData()
    }
    
    
   
    
    
    
}

extension YHServiceCenterSecondViewController {
    func loadData() {
        self.serviceCenterMainReqVM.getContactList { success, error in
            if success == true {
                
            }
            self.homeTableView.reloadData()
        }
    }
    
    func setupUI() {
        gk_navTitle = "服务中心"
        gk_navBarAlpha = 1.0
        gk_navLineHidden = false
        
        view.addSubview(topBkg)
        topBkg.snp.makeConstraints { make in
            make.top.left.right.equalToSuperview()
            make.height.equalTo(216)
        }
        
        view.addSubview(loginTipsView)
        loginTipsView.snp.makeConstraints { make in
            make.centerX.equalToSuperview()
            make.centerY.equalToSuperview().offset(-64)
            make.width.equalTo(KScreenWidth)
        }
        
        view.addSubview(noDataView)
        noDataView.snp.makeConstraints { make in
            make.centerX.equalToSuperview()
            make.centerY.equalToSuperview().offset(-64)
            make.width.equalTo(KScreenWidth)
        }
        
        view.addSubview(homeTableView)
        homeTableView.snp.makeConstraints { make in
            make.left.right.equalToSuperview()
            make.top.equalTo(k_Height_NavigationtBarAndStatuBar)
            make.bottom.equalToSuperview().offset(-k_Height_TabBar)
        }
        homeTableView.delegate = self
        homeTableView.dataSource = self
    }
    
    @objc func clickUnfoldView() {
        unfoldFlag = !unfoldFlag
        
        
        if unfoldFlag == true {
            UIView.animate(withDuration: 0.25) {
                self.downArrowImagev.transform = CGAffineTransform.identity
            }
        } else {
            UIView.animate(withDuration: 0.25) {
                self.downArrowImagev.transform = CGAffineTransform(rotationAngle: .pi)
            }
        }
        homeTableView.reloadSections(IndexSet(integer: 0), with: UITableView.RowAnimation.automatic)
    }
}

// MARK: - UITableViewDelegate 和 UITableViewDataSource
extension YHServiceCenterSecondViewController : UITableViewDelegate,UITableViewDataSource {
    func numberOfSections(in tableView: UITableView) -> Int {
        return 1
    }
    
    func tableView(_ tableView: UITableView, numberOfRowsInSection section: Int) -> Int {
        
        if unfoldFlag == true {
            return 1
        }
        return 0
    }
    
    func tableView(_ tableView: UITableView, heightForHeaderInSection section: Int) -> CGFloat {
        return 60
    }
    
    func tableView(_ tableView: UITableView, viewForHeaderInSection section: Int) -> UIView? {
        let view = UIView(frame: CGRect(x: 0, y: 0, width: KScreenWidth, height: 60))
        view.backgroundColor = .white
        
        let lable = UILabel(frame: CGRect(x: 16, y: 0, width: 200, height: 60))
        lable.text = "身份申请"
        lable.font = kFont(size: 17)
        view.addSubview(lable)
        view.addSubview(self.downArrowImagev)
        
        let tap = UITapGestureRecognizer(target: self, action: #selector(clickUnfoldView))
        view.addGestureRecognizer(tap)
        return view
    }
    
    func tableView(_ tableView: UITableView, heightForFooterInSection section: Int) -> CGFloat {
        return 0
    }
    
    func tableView(_ tableView: UITableView, viewForFooterInSection section: Int) -> UIView? {
        return UIView()
    }
    
    
    func tableView(_ tableView: UITableView, heightForRowAt indexPath: IndexPath) -> CGFloat {
        return UITableView.automaticDimension
    }
    
    func tableView(_ tableView: UITableView, cellForRowAt indexPath: IndexPath) -> UITableViewCell {
        if indexPath.row == 0 {
            let cell = tableView.dequeueReusableCell(withIdentifier: YHContractCell.cellReuseIdentifier, for: indexPath) as! YHContractCell
            cell.selectionStyle = .none
            
            if indexPath.section < self.serviceCenterMainReqVM.arrContactList.count {
                cell.dataModel = self.serviceCenterMainReqVM.arrContactList[indexPath.section]
            }
            return cell
        }
        return UITableViewCell()
    }
    
    func tableView(_ tableView: UITableView, didSelectRowAt indexPath: IndexPath) {
        tableView.deselectRow(at: indexPath, animated: true)
        if indexPath.row == 0 {
            printLog("点击了 0 row")
            
//            unfoldFlag = !unfoldFlag
            
        }
    }
}
